/****************************************************************************
** Meta object code from reading C++ file 'nettype.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../net-view/operation/nettype.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'nettype.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3dde7network7NetTypeE_t {};
} // unnamed namespace

template <> constexpr inline auto dde::network::NetType::qt_create_metaobjectdata<qt_meta_tag_ZN3dde7network7NetTypeE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dde::network::NetType",
        "NetItemType",
        "Item",
        "ConnectionItem",
        "WirelessControlItem",
        "WirelessDeviceItem",
        "WirelessMineItem",
        "WirelessOtherItem",
        "WirelessItem",
        "WirelessHiddenItem",
        "WirelessDisabledItem",
        "AirplaneModeTipsItem",
        "WiredControlItem",
        "WiredDeviceItem",
        "WiredItem",
        "WiredDisabledItem",
        "VPNControlItem",
        "VPNTipsItem",
        "SystemProxyControlItem",
        "AppProxyControlItem",
        "DSLControlItem",
        "HotspotControlItem",
        "AirplaneControlItem",
        "DetailsItem",
        "DetailsInfoItem",
        "NetConnectionStatus",
        "CS_UnConnected",
        "CS_Connecting",
        "CS_Connected",
        "CS_AllConnectionStatus",
        "NetDeviceStatus",
        "DS_Unknown",
        "DS_NoCable",
        "DS_Enabled",
        "DS_Unavailable",
        "DS_Disabled",
        "DS_ObtainIpFailed",
        "DS_ConnectFailed",
        "DS_Disconnected",
        "DS_Connected",
        "DS_ConnectNoInternet",
        "DS_IpConflicted",
        "DS_Connecting",
        "DS_ObtainingIP",
        "DS_Authenticating",
        "NetManagerFlag",
        "Net_ServiceNM",
        "Net_MonitorNotify",
        "Net_AutoAddConnection",
        "Net_UseSecretAgent",
        "Net_CheckPortal",
        "Net_tipsLinkEnabled",
        "Net_autoUpdateHiddenConfig",
        "Net_8021xToConnect",
        "Net_8021xToControlCenter",
        "Net_8021xSendNotify",
        "Net_8021xUnderConnect",
        "Net_8021xToControlCenterUnderConnect",
        "Net_8021xSendNotifyUnderConnect",
        "Net_Device",
        "Net_VPN",
        "Net_SysProxy",
        "Net_AppProxy",
        "Net_Hotspot",
        "Net_Airplane",
        "Net_DSL",
        "Net_Details",
        "Net_AirplaneTips",
        "Net_VPNTips",
        "Net_VPNChildren",
        "Net_DockFlags",
        "Net_LockFlags",
        "Net_GreeterFlags",
        "Net_DccFlags",
        "Net_8021xMask",
        "ProxyMethod",
        "Init",
        "None",
        "Auto",
        "Manual",
        "ProxyType",
        "Http",
        "Https",
        "Ftp",
        "Socks",
        "Socks4",
        "Socks5"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'NetItemType'
        QtMocHelpers::EnumData<enum NetItemType>(1, 1, QMC::EnumFlags{}).add({
            {    2, NetItemType::Item },
            {    3, NetItemType::ConnectionItem },
            {    4, NetItemType::WirelessControlItem },
            {    5, NetItemType::WirelessDeviceItem },
            {    6, NetItemType::WirelessMineItem },
            {    7, NetItemType::WirelessOtherItem },
            {    8, NetItemType::WirelessItem },
            {    9, NetItemType::WirelessHiddenItem },
            {   10, NetItemType::WirelessDisabledItem },
            {   11, NetItemType::AirplaneModeTipsItem },
            {   12, NetItemType::WiredControlItem },
            {   13, NetItemType::WiredDeviceItem },
            {   14, NetItemType::WiredItem },
            {   15, NetItemType::WiredDisabledItem },
            {   16, NetItemType::VPNControlItem },
            {   17, NetItemType::VPNTipsItem },
            {   18, NetItemType::SystemProxyControlItem },
            {   19, NetItemType::AppProxyControlItem },
            {   20, NetItemType::DSLControlItem },
            {   21, NetItemType::HotspotControlItem },
            {   22, NetItemType::AirplaneControlItem },
            {   23, NetItemType::DetailsItem },
            {   24, NetItemType::DetailsInfoItem },
        }),
        // enum 'NetConnectionStatus'
        QtMocHelpers::EnumData<enum NetConnectionStatus>(25, 25, QMC::EnumFlags{}).add({
            {   26, NetConnectionStatus::CS_UnConnected },
            {   27, NetConnectionStatus::CS_Connecting },
            {   28, NetConnectionStatus::CS_Connected },
            {   29, NetConnectionStatus::CS_AllConnectionStatus },
        }),
        // enum 'NetDeviceStatus'
        QtMocHelpers::EnumData<enum NetDeviceStatus>(30, 30, QMC::EnumFlags{}).add({
            {   31, NetDeviceStatus::DS_Unknown },
            {   32, NetDeviceStatus::DS_NoCable },
            {   33, NetDeviceStatus::DS_Enabled },
            {   34, NetDeviceStatus::DS_Unavailable },
            {   35, NetDeviceStatus::DS_Disabled },
            {   36, NetDeviceStatus::DS_ObtainIpFailed },
            {   37, NetDeviceStatus::DS_ConnectFailed },
            {   38, NetDeviceStatus::DS_Disconnected },
            {   39, NetDeviceStatus::DS_Connected },
            {   40, NetDeviceStatus::DS_ConnectNoInternet },
            {   41, NetDeviceStatus::DS_IpConflicted },
            {   42, NetDeviceStatus::DS_Connecting },
            {   43, NetDeviceStatus::DS_ObtainingIP },
            {   44, NetDeviceStatus::DS_Authenticating },
        }),
        // enum 'NetManagerFlag'
        QtMocHelpers::EnumData<enum NetManagerFlag>(45, 45, QMC::EnumFlags{}).add({
            {   46, NetManagerFlag::Net_ServiceNM },
            {   47, NetManagerFlag::Net_MonitorNotify },
            {   48, NetManagerFlag::Net_AutoAddConnection },
            {   49, NetManagerFlag::Net_UseSecretAgent },
            {   50, NetManagerFlag::Net_CheckPortal },
            {   51, NetManagerFlag::Net_tipsLinkEnabled },
            {   52, NetManagerFlag::Net_autoUpdateHiddenConfig },
            {   53, NetManagerFlag::Net_8021xToConnect },
            {   54, NetManagerFlag::Net_8021xToControlCenter },
            {   55, NetManagerFlag::Net_8021xSendNotify },
            {   56, NetManagerFlag::Net_8021xUnderConnect },
            {   57, NetManagerFlag::Net_8021xToControlCenterUnderConnect },
            {   58, NetManagerFlag::Net_8021xSendNotifyUnderConnect },
            {   59, NetManagerFlag::Net_Device },
            {   60, NetManagerFlag::Net_VPN },
            {   61, NetManagerFlag::Net_SysProxy },
            {   62, NetManagerFlag::Net_AppProxy },
            {   63, NetManagerFlag::Net_Hotspot },
            {   64, NetManagerFlag::Net_Airplane },
            {   65, NetManagerFlag::Net_DSL },
            {   66, NetManagerFlag::Net_Details },
            {   67, NetManagerFlag::Net_AirplaneTips },
            {   68, NetManagerFlag::Net_VPNTips },
            {   69, NetManagerFlag::Net_VPNChildren },
            {   70, NetManagerFlag::Net_DockFlags },
            {   71, NetManagerFlag::Net_LockFlags },
            {   72, NetManagerFlag::Net_GreeterFlags },
            {   73, NetManagerFlag::Net_DccFlags },
            {   74, NetManagerFlag::Net_8021xMask },
        }),
        // enum 'ProxyMethod'
        QtMocHelpers::EnumData<enum ProxyMethod>(75, 75, QMC::EnumFlags{}).add({
            {   76, ProxyMethod::Init },
            {   77, ProxyMethod::None },
            {   78, ProxyMethod::Auto },
            {   79, ProxyMethod::Manual },
        }),
        // enum 'ProxyType'
        QtMocHelpers::EnumData<enum ProxyType>(80, 80, QMC::EnumFlags{}).add({
            {   81, ProxyType::Http },
            {   82, ProxyType::Https },
            {   83, ProxyType::Ftp },
            {   84, ProxyType::Socks },
            {   85, ProxyType::Socks4 },
            {   86, ProxyType::Socks5 },
        }),
    };
    return QtMocHelpers::metaObjectData<NetType, qt_meta_tag_ZN3dde7network7NetTypeE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dde::network::NetType::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network7NetTypeE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network7NetTypeE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3dde7network7NetTypeE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN3dde7networkE_t {};
} // unnamed namespace

template <> constexpr inline auto dde::network::qt_create_metaobjectdata<qt_meta_tag_ZN3dde7networkE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dde::network"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN3dde7networkE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN3dde7networkE =
    dde::network::qt_create_metaobjectdata<qt_meta_tag_ZN3dde7networkE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN3dde7networkE =
    qt_staticMetaObjectContent_ZN3dde7networkE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN3dde7networkE =
    qt_staticMetaObjectContent_ZN3dde7networkE.relocatingData;

Q_CONSTINIT const QMetaObject dde::network::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN3dde7networkE.stringdata,
    qt_staticMetaObjectStaticContent_ZN3dde7networkE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN3dde7networkE.metaTypes,
    nullptr
} };

QT_WARNING_POP
