/****************************************************************************
** Meta object code from reading C++ file 'configsetting.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../configsetting.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'configsetting.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3dde7network13ConfigSettingE_t {};
} // unnamed namespace

template <> constexpr inline auto dde::network::ConfigSetting::qt_create_metaobjectdata<qt_meta_tag_ZN3dde7network13ConfigSettingE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dde::network::ConfigSetting",
        "checkUrlsChanged",
        "",
        "enableConnectivityChanged",
        "checkPortalChanged",
        "connectivityCheckIntervalChanged",
        "wirelessScanIntervalChanged",
        "wpaEapAuthenChanged",
        "wpaEapAuthmethodChanged",
        "enableAirplaneModeChanged",
        "supportCertifiedEscapeChanged",
        "showUnAuthorizeSwitchChanged",
        "showBrowserLinkChanged",
        "browserUrlChanged",
        "onValueChanged",
        "key"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'checkUrlsChanged'
        QtMocHelpers::SignalData<void(const QStringList &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 2 },
        }}),
        // Signal 'enableConnectivityChanged'
        QtMocHelpers::SignalData<void(bool)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'checkPortalChanged'
        QtMocHelpers::SignalData<void(bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'connectivityCheckIntervalChanged'
        QtMocHelpers::SignalData<void(int)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'wirelessScanIntervalChanged'
        QtMocHelpers::SignalData<void(int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'wpaEapAuthenChanged'
        QtMocHelpers::SignalData<void(const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'wpaEapAuthmethodChanged'
        QtMocHelpers::SignalData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'enableAirplaneModeChanged'
        QtMocHelpers::SignalData<void(bool)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'supportCertifiedEscapeChanged'
        QtMocHelpers::SignalData<void(bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'showUnAuthorizeSwitchChanged'
        QtMocHelpers::SignalData<void(bool)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'showBrowserLinkChanged'
        QtMocHelpers::SignalData<void(bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'browserUrlChanged'
        QtMocHelpers::SignalData<void(const QString &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'onValueChanged'
        QtMocHelpers::SlotData<void(const QString &)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ConfigSetting, qt_meta_tag_ZN3dde7network13ConfigSettingE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dde::network::ConfigSetting::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network13ConfigSettingE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network13ConfigSettingE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3dde7network13ConfigSettingE_t>.metaTypes,
    nullptr
} };

void dde::network::ConfigSetting::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ConfigSetting *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->checkUrlsChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 1: _t->enableConnectivityChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->checkPortalChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->connectivityCheckIntervalChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->wirelessScanIntervalChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->wpaEapAuthenChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->wpaEapAuthmethodChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->enableAirplaneModeChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->supportCertifiedEscapeChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->showUnAuthorizeSwitchChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->showBrowserLinkChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->browserUrlChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->onValueChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ConfigSetting::*)(const QStringList & )>(_a, &ConfigSetting::checkUrlsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ConfigSetting::*)(bool )>(_a, &ConfigSetting::enableConnectivityChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ConfigSetting::*)(bool )>(_a, &ConfigSetting::checkPortalChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ConfigSetting::*)(int )>(_a, &ConfigSetting::connectivityCheckIntervalChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ConfigSetting::*)(int )>(_a, &ConfigSetting::wirelessScanIntervalChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ConfigSetting::*)(const QString & )>(_a, &ConfigSetting::wpaEapAuthenChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ConfigSetting::*)(const QString & )>(_a, &ConfigSetting::wpaEapAuthmethodChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ConfigSetting::*)(bool )>(_a, &ConfigSetting::enableAirplaneModeChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (ConfigSetting::*)(bool )>(_a, &ConfigSetting::supportCertifiedEscapeChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (ConfigSetting::*)(bool )>(_a, &ConfigSetting::showUnAuthorizeSwitchChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (ConfigSetting::*)(bool )>(_a, &ConfigSetting::showBrowserLinkChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (ConfigSetting::*)(const QString & )>(_a, &ConfigSetting::browserUrlChanged, 11))
            return;
    }
}

const QMetaObject *dde::network::ConfigSetting::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dde::network::ConfigSetting::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network13ConfigSettingE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dde::network::ConfigSetting::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void dde::network::ConfigSetting::checkUrlsChanged(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void dde::network::ConfigSetting::enableConnectivityChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void dde::network::ConfigSetting::checkPortalChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void dde::network::ConfigSetting::connectivityCheckIntervalChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void dde::network::ConfigSetting::wirelessScanIntervalChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void dde::network::ConfigSetting::wpaEapAuthenChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void dde::network::ConfigSetting::wpaEapAuthmethodChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void dde::network::ConfigSetting::enableAirplaneModeChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void dde::network::ConfigSetting::supportCertifiedEscapeChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void dde::network::ConfigSetting::showUnAuthorizeSwitchChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void dde::network::ConfigSetting::showBrowserLinkChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void dde::network::ConfigSetting::browserUrlChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}
QT_WARNING_POP
