/****************************************************************************
** Meta object code from reading C++ file 'wireddevice.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../wireddevice.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'wireddevice.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3dde7network11WiredDeviceE_t {};
} // unnamed namespace

template <> constexpr inline auto dde::network::WiredDevice::qt_create_metaobjectdata<qt_meta_tag_ZN3dde7network11WiredDeviceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dde::network::WiredDevice",
        "connectionAdded",
        "",
        "QList<WiredConnection*>",
        "connectionRemoved",
        "connectionPropertyChanged",
        "carrierChanged",
        "carrier"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'connectionAdded'
        QtMocHelpers::SignalData<void(const QList<WiredConnection*> &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'connectionRemoved'
        QtMocHelpers::SignalData<void(const QList<WiredConnection*> &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'connectionPropertyChanged'
        QtMocHelpers::SignalData<void(const QList<WiredConnection*> &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'carrierChanged'
        QtMocHelpers::SignalData<void(bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<WiredDevice, qt_meta_tag_ZN3dde7network11WiredDeviceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dde::network::WiredDevice::staticMetaObject = { {
    QMetaObject::SuperData::link<NetworkDeviceBase::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network11WiredDeviceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network11WiredDeviceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3dde7network11WiredDeviceE_t>.metaTypes,
    nullptr
} };

void dde::network::WiredDevice::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WiredDevice *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->connectionAdded((*reinterpret_cast<std::add_pointer_t<QList<WiredConnection*>>>(_a[1]))); break;
        case 1: _t->connectionRemoved((*reinterpret_cast<std::add_pointer_t<QList<WiredConnection*>>>(_a[1]))); break;
        case 2: _t->connectionPropertyChanged((*reinterpret_cast<std::add_pointer_t<QList<WiredConnection*>>>(_a[1]))); break;
        case 3: _t->carrierChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<WiredConnection*> >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<WiredConnection*> >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<WiredConnection*> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (WiredDevice::*)(const QList<WiredConnection*> & )>(_a, &WiredDevice::connectionAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (WiredDevice::*)(const QList<WiredConnection*> & )>(_a, &WiredDevice::connectionRemoved, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (WiredDevice::*)(const QList<WiredConnection*> & )>(_a, &WiredDevice::connectionPropertyChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (WiredDevice::*)(bool )>(_a, &WiredDevice::carrierChanged, 3))
            return;
    }
}

const QMetaObject *dde::network::WiredDevice::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dde::network::WiredDevice::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network11WiredDeviceE_t>.strings))
        return static_cast<void*>(this);
    return NetworkDeviceBase::qt_metacast(_clname);
}

int dde::network::WiredDevice::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = NetworkDeviceBase::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void dde::network::WiredDevice::connectionAdded(const QList<WiredConnection*> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void dde::network::WiredDevice::connectionRemoved(const QList<WiredConnection*> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void dde::network::WiredDevice::connectionPropertyChanged(const QList<WiredConnection*> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void dde::network::WiredDevice::carrierChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN3dde7network15WiredConnectionE_t {};
} // unnamed namespace

template <> constexpr inline auto dde::network::WiredConnection::qt_create_metaobjectdata<qt_meta_tag_ZN3dde7network15WiredConnectionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dde::network::WiredConnection"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<WiredConnection, qt_meta_tag_ZN3dde7network15WiredConnectionE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dde::network::WiredConnection::staticMetaObject = { {
    QMetaObject::SuperData::link<ControllItems::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network15WiredConnectionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network15WiredConnectionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3dde7network15WiredConnectionE_t>.metaTypes,
    nullptr
} };

void dde::network::WiredConnection::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WiredConnection *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *dde::network::WiredConnection::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dde::network::WiredConnection::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network15WiredConnectionE_t>.strings))
        return static_cast<void*>(this);
    return ControllItems::qt_metacast(_clname);
}

int dde::network::WiredConnection::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ControllItems::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
