/****************************************************************************
** Meta object code from reading C++ file 'netinterface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../impl/netinterface.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'netinterface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3dde7network16NetworkProcesserE_t {};
} // unnamed namespace

template <> constexpr inline auto dde::network::NetworkProcesser::qt_create_metaobjectdata<qt_meta_tag_ZN3dde7network16NetworkProcesserE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dde::network::NetworkProcesser",
        "deviceAdded",
        "",
        "QList<NetworkDeviceBase*>",
        "deviceRemoved",
        "connectivityChanged",
        "Connectivity",
        "connectionChanged",
        "activeConnectionChange",
        "onIpConflictChanged",
        "devicePath",
        "ip",
        "conflicted"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'deviceAdded'
        QtMocHelpers::SignalData<void(QList<NetworkDeviceBase*>)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'deviceRemoved'
        QtMocHelpers::SignalData<void(QList<NetworkDeviceBase*>)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'connectivityChanged'
        QtMocHelpers::SignalData<void(const Connectivity &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Signal 'connectionChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activeConnectionChange'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onIpConflictChanged'
        QtMocHelpers::SlotData<void(const QString &, const QString &, bool)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 }, { QMetaType::QString, 11 }, { QMetaType::Bool, 12 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NetworkProcesser, qt_meta_tag_ZN3dde7network16NetworkProcesserE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dde::network::NetworkProcesser::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network16NetworkProcesserE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network16NetworkProcesserE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3dde7network16NetworkProcesserE_t>.metaTypes,
    nullptr
} };

void dde::network::NetworkProcesser::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NetworkProcesser *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->deviceAdded((*reinterpret_cast<std::add_pointer_t<QList<NetworkDeviceBase*>>>(_a[1]))); break;
        case 1: _t->deviceRemoved((*reinterpret_cast<std::add_pointer_t<QList<NetworkDeviceBase*>>>(_a[1]))); break;
        case 2: _t->connectivityChanged((*reinterpret_cast<std::add_pointer_t<Connectivity>>(_a[1]))); break;
        case 3: _t->connectionChanged(); break;
        case 4: _t->activeConnectionChange(); break;
        case 5: _t->onIpConflictChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (NetworkProcesser::*)(QList<NetworkDeviceBase*> )>(_a, &NetworkProcesser::deviceAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetworkProcesser::*)(QList<NetworkDeviceBase*> )>(_a, &NetworkProcesser::deviceRemoved, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetworkProcesser::*)(const Connectivity & )>(_a, &NetworkProcesser::connectivityChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetworkProcesser::*)()>(_a, &NetworkProcesser::connectionChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetworkProcesser::*)()>(_a, &NetworkProcesser::activeConnectionChange, 4))
            return;
    }
}

const QMetaObject *dde::network::NetworkProcesser::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dde::network::NetworkProcesser::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network16NetworkProcesserE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dde::network::NetworkProcesser::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void dde::network::NetworkProcesser::deviceAdded(QList<NetworkDeviceBase*> _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void dde::network::NetworkProcesser::deviceRemoved(QList<NetworkDeviceBase*> _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void dde::network::NetworkProcesser::connectivityChanged(const Connectivity & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void dde::network::NetworkProcesser::connectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void dde::network::NetworkProcesser::activeConnectionChange()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
namespace {
struct qt_meta_tag_ZN3dde7network20NetworkDeviceRealizeE_t {};
} // unnamed namespace

template <> constexpr inline auto dde::network::NetworkDeviceRealize::qt_create_metaobjectdata<qt_meta_tag_ZN3dde7network20NetworkDeviceRealizeE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dde::network::NetworkDeviceRealize",
        "deviceStatusChanged",
        "",
        "DeviceStatus",
        "enableChanged",
        "connectionChanged",
        "nameChanged",
        "removed",
        "networkAdded",
        "QList<AccessPoints*>",
        "networkRemoved",
        "connectionFailed",
        "const AccessPoints*",
        "connectionSuccess",
        "hotspotEnableChanged",
        "accessPointInfoChanged",
        "activeConnectionChanged",
        "wirelessConnectionAdded",
        "QList<WirelessConnection*>",
        "wirelessConnectionRemoved",
        "wirelessConnectionPropertyChanged",
        "connectionAdded",
        "QList<WiredConnection*>",
        "connectionRemoved",
        "connectionPropertyChanged",
        "ipV4Changed",
        "availableChanged",
        "carrierChanged",
        "carrier"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'deviceStatusChanged'
        QtMocHelpers::SignalData<void(const DeviceStatus &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'enableChanged'
        QtMocHelpers::SignalData<void(const bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'connectionChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'removed'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'networkAdded'
        QtMocHelpers::SignalData<void(const QList<AccessPoints*> &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 2 },
        }}),
        // Signal 'networkRemoved'
        QtMocHelpers::SignalData<void(const QList<AccessPoints*> &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 2 },
        }}),
        // Signal 'connectionFailed'
        QtMocHelpers::SignalData<void(const AccessPoints *)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 2 },
        }}),
        // Signal 'connectionSuccess'
        QtMocHelpers::SignalData<void(const AccessPoints *)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 2 },
        }}),
        // Signal 'hotspotEnableChanged'
        QtMocHelpers::SignalData<void(const bool &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'accessPointInfoChanged'
        QtMocHelpers::SignalData<void(const QList<AccessPoints*> &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 2 },
        }}),
        // Signal 'activeConnectionChanged'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'wirelessConnectionAdded'
        QtMocHelpers::SignalData<void(const QList<WirelessConnection*> &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 2 },
        }}),
        // Signal 'wirelessConnectionRemoved'
        QtMocHelpers::SignalData<void(const QList<WirelessConnection*> &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 2 },
        }}),
        // Signal 'wirelessConnectionPropertyChanged'
        QtMocHelpers::SignalData<void(const QList<WirelessConnection*> &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 2 },
        }}),
        // Signal 'connectionAdded'
        QtMocHelpers::SignalData<void(const QList<WiredConnection*> &)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 2 },
        }}),
        // Signal 'connectionRemoved'
        QtMocHelpers::SignalData<void(const QList<WiredConnection*> &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 2 },
        }}),
        // Signal 'connectionPropertyChanged'
        QtMocHelpers::SignalData<void(const QList<WiredConnection*> &)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 2 },
        }}),
        // Signal 'ipV4Changed'
        QtMocHelpers::SignalData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'availableChanged'
        QtMocHelpers::SignalData<void(bool)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'carrierChanged'
        QtMocHelpers::SignalData<void(bool)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 28 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NetworkDeviceRealize, qt_meta_tag_ZN3dde7network20NetworkDeviceRealizeE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dde::network::NetworkDeviceRealize::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network20NetworkDeviceRealizeE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network20NetworkDeviceRealizeE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3dde7network20NetworkDeviceRealizeE_t>.metaTypes,
    nullptr
} };

void dde::network::NetworkDeviceRealize::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NetworkDeviceRealize *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->deviceStatusChanged((*reinterpret_cast<std::add_pointer_t<DeviceStatus>>(_a[1]))); break;
        case 1: _t->enableChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->connectionChanged(); break;
        case 3: _t->nameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->removed(); break;
        case 5: _t->networkAdded((*reinterpret_cast<std::add_pointer_t<QList<AccessPoints*>>>(_a[1]))); break;
        case 6: _t->networkRemoved((*reinterpret_cast<std::add_pointer_t<QList<AccessPoints*>>>(_a[1]))); break;
        case 7: _t->connectionFailed((*reinterpret_cast<std::add_pointer_t<const AccessPoints*>>(_a[1]))); break;
        case 8: _t->connectionSuccess((*reinterpret_cast<std::add_pointer_t<const AccessPoints*>>(_a[1]))); break;
        case 9: _t->hotspotEnableChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->accessPointInfoChanged((*reinterpret_cast<std::add_pointer_t<QList<AccessPoints*>>>(_a[1]))); break;
        case 11: _t->activeConnectionChanged(); break;
        case 12: _t->wirelessConnectionAdded((*reinterpret_cast<std::add_pointer_t<QList<WirelessConnection*>>>(_a[1]))); break;
        case 13: _t->wirelessConnectionRemoved((*reinterpret_cast<std::add_pointer_t<QList<WirelessConnection*>>>(_a[1]))); break;
        case 14: _t->wirelessConnectionPropertyChanged((*reinterpret_cast<std::add_pointer_t<QList<WirelessConnection*>>>(_a[1]))); break;
        case 15: _t->connectionAdded((*reinterpret_cast<std::add_pointer_t<QList<WiredConnection*>>>(_a[1]))); break;
        case 16: _t->connectionRemoved((*reinterpret_cast<std::add_pointer_t<QList<WiredConnection*>>>(_a[1]))); break;
        case 17: _t->connectionPropertyChanged((*reinterpret_cast<std::add_pointer_t<QList<WiredConnection*>>>(_a[1]))); break;
        case 18: _t->ipV4Changed(); break;
        case 19: _t->availableChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 20: _t->carrierChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (NetworkDeviceRealize::*)(const DeviceStatus & )>(_a, &NetworkDeviceRealize::deviceStatusChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetworkDeviceRealize::*)(const bool )>(_a, &NetworkDeviceRealize::enableChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetworkDeviceRealize::*)()>(_a, &NetworkDeviceRealize::connectionChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetworkDeviceRealize::*)(const QString & )>(_a, &NetworkDeviceRealize::nameChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetworkDeviceRealize::*)()>(_a, &NetworkDeviceRealize::removed, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetworkDeviceRealize::*)(const QList<AccessPoints*> & )>(_a, &NetworkDeviceRealize::networkAdded, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetworkDeviceRealize::*)(const QList<AccessPoints*> & )>(_a, &NetworkDeviceRealize::networkRemoved, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetworkDeviceRealize::*)(const AccessPoints * )>(_a, &NetworkDeviceRealize::connectionFailed, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetworkDeviceRealize::*)(const AccessPoints * )>(_a, &NetworkDeviceRealize::connectionSuccess, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetworkDeviceRealize::*)(const bool & )>(_a, &NetworkDeviceRealize::hotspotEnableChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetworkDeviceRealize::*)(const QList<AccessPoints*> & )>(_a, &NetworkDeviceRealize::accessPointInfoChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetworkDeviceRealize::*)()>(_a, &NetworkDeviceRealize::activeConnectionChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetworkDeviceRealize::*)(const QList<WirelessConnection*> & )>(_a, &NetworkDeviceRealize::wirelessConnectionAdded, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetworkDeviceRealize::*)(const QList<WirelessConnection*> & )>(_a, &NetworkDeviceRealize::wirelessConnectionRemoved, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetworkDeviceRealize::*)(const QList<WirelessConnection*> & )>(_a, &NetworkDeviceRealize::wirelessConnectionPropertyChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetworkDeviceRealize::*)(const QList<WiredConnection*> & )>(_a, &NetworkDeviceRealize::connectionAdded, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetworkDeviceRealize::*)(const QList<WiredConnection*> & )>(_a, &NetworkDeviceRealize::connectionRemoved, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetworkDeviceRealize::*)(const QList<WiredConnection*> & )>(_a, &NetworkDeviceRealize::connectionPropertyChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetworkDeviceRealize::*)()>(_a, &NetworkDeviceRealize::ipV4Changed, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetworkDeviceRealize::*)(bool )>(_a, &NetworkDeviceRealize::availableChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetworkDeviceRealize::*)(bool )>(_a, &NetworkDeviceRealize::carrierChanged, 20))
            return;
    }
}

const QMetaObject *dde::network::NetworkDeviceRealize::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dde::network::NetworkDeviceRealize::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network20NetworkDeviceRealizeE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dde::network::NetworkDeviceRealize::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 21;
    }
    return _id;
}

// SIGNAL 0
void dde::network::NetworkDeviceRealize::deviceStatusChanged(const DeviceStatus & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void dde::network::NetworkDeviceRealize::enableChanged(const bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void dde::network::NetworkDeviceRealize::connectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void dde::network::NetworkDeviceRealize::nameChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void dde::network::NetworkDeviceRealize::removed()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void dde::network::NetworkDeviceRealize::networkAdded(const QList<AccessPoints*> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void dde::network::NetworkDeviceRealize::networkRemoved(const QList<AccessPoints*> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void dde::network::NetworkDeviceRealize::connectionFailed(const AccessPoints * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void dde::network::NetworkDeviceRealize::connectionSuccess(const AccessPoints * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void dde::network::NetworkDeviceRealize::hotspotEnableChanged(const bool & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void dde::network::NetworkDeviceRealize::accessPointInfoChanged(const QList<AccessPoints*> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void dde::network::NetworkDeviceRealize::activeConnectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void dde::network::NetworkDeviceRealize::wirelessConnectionAdded(const QList<WirelessConnection*> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void dde::network::NetworkDeviceRealize::wirelessConnectionRemoved(const QList<WirelessConnection*> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void dde::network::NetworkDeviceRealize::wirelessConnectionPropertyChanged(const QList<WirelessConnection*> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void dde::network::NetworkDeviceRealize::connectionAdded(const QList<WiredConnection*> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void dde::network::NetworkDeviceRealize::connectionRemoved(const QList<WiredConnection*> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void dde::network::NetworkDeviceRealize::connectionPropertyChanged(const QList<WiredConnection*> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void dde::network::NetworkDeviceRealize::ipV4Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void dde::network::NetworkDeviceRealize::availableChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1);
}

// SIGNAL 20
void dde::network::NetworkDeviceRealize::carrierChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 20, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN3dde7network20NetworkDetailRealizeE_t {};
} // unnamed namespace

template <> constexpr inline auto dde::network::NetworkDetailRealize::qt_create_metaobjectdata<qt_meta_tag_ZN3dde7network20NetworkDetailRealizeE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dde::network::NetworkDetailRealize",
        "infoChanged",
        ""
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'infoChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NetworkDetailRealize, qt_meta_tag_ZN3dde7network20NetworkDetailRealizeE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dde::network::NetworkDetailRealize::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network20NetworkDetailRealizeE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network20NetworkDetailRealizeE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3dde7network20NetworkDetailRealizeE_t>.metaTypes,
    nullptr
} };

void dde::network::NetworkDetailRealize::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NetworkDetailRealize *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->infoChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (NetworkDetailRealize::*)()>(_a, &NetworkDetailRealize::infoChanged, 0))
            return;
    }
}

const QMetaObject *dde::network::NetworkDetailRealize::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dde::network::NetworkDetailRealize::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network20NetworkDetailRealizeE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dde::network::NetworkDetailRealize::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void dde::network::NetworkDetailRealize::infoChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
namespace {
struct qt_meta_tag_ZN3dde7network16AccessPointProxyE_t {};
} // unnamed namespace

template <> constexpr inline auto dde::network::AccessPointProxy::qt_create_metaobjectdata<qt_meta_tag_ZN3dde7network16AccessPointProxyE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dde::network::AccessPointProxy",
        "strengthChanged",
        "",
        "connectionStatusChanged",
        "ConnectionStatus",
        "securedChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'strengthChanged'
        QtMocHelpers::SignalData<void(const int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'connectionStatusChanged'
        QtMocHelpers::SignalData<void(ConnectionStatus)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 2 },
        }}),
        // Signal 'securedChanged'
        QtMocHelpers::SignalData<void(bool)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AccessPointProxy, qt_meta_tag_ZN3dde7network16AccessPointProxyE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dde::network::AccessPointProxy::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network16AccessPointProxyE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network16AccessPointProxyE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3dde7network16AccessPointProxyE_t>.metaTypes,
    nullptr
} };

void dde::network::AccessPointProxy::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AccessPointProxy *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->strengthChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->connectionStatusChanged((*reinterpret_cast<std::add_pointer_t<ConnectionStatus>>(_a[1]))); break;
        case 2: _t->securedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AccessPointProxy::*)(const int )>(_a, &AccessPointProxy::strengthChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccessPointProxy::*)(ConnectionStatus )>(_a, &AccessPointProxy::connectionStatusChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccessPointProxy::*)(bool )>(_a, &AccessPointProxy::securedChanged, 2))
            return;
    }
}

const QMetaObject *dde::network::AccessPointProxy::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dde::network::AccessPointProxy::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network16AccessPointProxyE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dde::network::AccessPointProxy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void dde::network::AccessPointProxy::strengthChanged(const int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void dde::network::AccessPointProxy::connectionStatusChanged(ConnectionStatus _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void dde::network::AccessPointProxy::securedChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
