/****************************************************************************
** Meta object code from reading C++ file 'networkdevicebase.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../networkdevicebase.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'networkdevicebase.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3dde7network17NetworkDeviceBaseE_t {};
} // unnamed namespace

template <> constexpr inline auto dde::network::NetworkDeviceBase::qt_create_metaobjectdata<qt_meta_tag_ZN3dde7network17NetworkDeviceBaseE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dde::network::NetworkDeviceBase",
        "deviceStatusChanged",
        "",
        "DeviceStatus",
        "enableChanged",
        "connectionChanged",
        "nameChanged",
        "removed",
        "activeConnectionChanged",
        "ipV4Changed",
        "availableChanged",
        "statusName",
        "statusDetail",
        "enabled",
        "IPValid",
        "interface",
        "driver",
        "managed",
        "vendor",
        "uniqueUuid",
        "usbDevice",
        "path",
        "activeAp",
        "supportHotspot",
        "realHwAdr",
        "usingHwAdr",
        "ipv4",
        "ipv6",
        "deviceName",
        "available"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'deviceStatusChanged'
        QtMocHelpers::SignalData<void(const DeviceStatus &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'enableChanged'
        QtMocHelpers::SignalData<void(const bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'connectionChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'removed'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activeConnectionChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ipV4Changed'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'availableChanged'
        QtMocHelpers::SignalData<void(bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'statusName'
        QtMocHelpers::PropertyData<QString>(11, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'statusDetail'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'enabled'
        QtMocHelpers::PropertyData<bool>(13, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'IPValid'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'interface'
        QtMocHelpers::PropertyData<QString>(15, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'driver'
        QtMocHelpers::PropertyData<QString>(16, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'managed'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'vendor'
        QtMocHelpers::PropertyData<QString>(18, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'uniqueUuid'
        QtMocHelpers::PropertyData<QString>(19, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'usbDevice'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'path'
        QtMocHelpers::PropertyData<QString>(21, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'activeAp'
        QtMocHelpers::PropertyData<QString>(22, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'supportHotspot'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'realHwAdr'
        QtMocHelpers::PropertyData<QString>(24, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'usingHwAdr'
        QtMocHelpers::PropertyData<QString>(25, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'ipv4'
        QtMocHelpers::PropertyData<QStringList>(26, QMetaType::QStringList, QMC::DefaultPropertyFlags),
        // property 'ipv6'
        QtMocHelpers::PropertyData<QStringList>(27, QMetaType::QStringList, QMC::DefaultPropertyFlags),
        // property 'deviceName'
        QtMocHelpers::PropertyData<QString>(28, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 3),
        // property 'available'
        QtMocHelpers::PropertyData<bool>(29, QMetaType::Bool, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NetworkDeviceBase, qt_meta_tag_ZN3dde7network17NetworkDeviceBaseE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dde::network::NetworkDeviceBase::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network17NetworkDeviceBaseE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network17NetworkDeviceBaseE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3dde7network17NetworkDeviceBaseE_t>.metaTypes,
    nullptr
} };

void dde::network::NetworkDeviceBase::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NetworkDeviceBase *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->deviceStatusChanged((*reinterpret_cast<std::add_pointer_t<DeviceStatus>>(_a[1]))); break;
        case 1: _t->enableChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->connectionChanged(); break;
        case 3: _t->nameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->removed(); break;
        case 5: _t->activeConnectionChanged(); break;
        case 6: _t->ipV4Changed(); break;
        case 7: _t->availableChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (NetworkDeviceBase::*)(const DeviceStatus & )>(_a, &NetworkDeviceBase::deviceStatusChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetworkDeviceBase::*)(const bool )>(_a, &NetworkDeviceBase::enableChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetworkDeviceBase::*)()>(_a, &NetworkDeviceBase::connectionChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetworkDeviceBase::*)(const QString & )>(_a, &NetworkDeviceBase::nameChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetworkDeviceBase::*)()>(_a, &NetworkDeviceBase::removed, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetworkDeviceBase::*)()>(_a, &NetworkDeviceBase::activeConnectionChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetworkDeviceBase::*)()>(_a, &NetworkDeviceBase::ipV4Changed, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetworkDeviceBase::*)(bool )>(_a, &NetworkDeviceBase::availableChanged, 7))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->getStatusName(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->statusStringDetail(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->isEnabled(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->IPValid(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->interface(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->driver(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->managed(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->vendor(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->uniqueUuid(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->usbDevice(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->path(); break;
        case 11: *reinterpret_cast<QString*>(_v) = _t->activeAp(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->supportHotspot(); break;
        case 13: *reinterpret_cast<QString*>(_v) = _t->realHwAdr(); break;
        case 14: *reinterpret_cast<QString*>(_v) = _t->usingHwAdr(); break;
        case 15: *reinterpret_cast<QStringList*>(_v) = _t->ipv4(); break;
        case 16: *reinterpret_cast<QStringList*>(_v) = _t->ipv6(); break;
        case 17: *reinterpret_cast<QString*>(_v) = _t->deviceName(); break;
        case 18: *reinterpret_cast<bool*>(_v) = _t->available(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 17: _t->setName(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *dde::network::NetworkDeviceBase::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dde::network::NetworkDeviceBase::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network17NetworkDeviceBaseE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dde::network::NetworkDeviceBase::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    return _id;
}

// SIGNAL 0
void dde::network::NetworkDeviceBase::deviceStatusChanged(const DeviceStatus & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void dde::network::NetworkDeviceBase::enableChanged(const bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void dde::network::NetworkDeviceBase::connectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void dde::network::NetworkDeviceBase::nameChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void dde::network::NetworkDeviceBase::removed()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void dde::network::NetworkDeviceBase::activeConnectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void dde::network::NetworkDeviceBase::ipV4Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void dde::network::NetworkDeviceBase::availableChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}
QT_WARNING_POP
